@@ -6,7 +6,7 @@ from .twitter_sent import TwitterSentBenchmark  # noqa
 from .europarl import EuroparlBenchmark  # noqa
 from .lcc import LccBenchmark  # noqa
 from .dkhate import DkHateBenchmark  # noqa
-from .norec import NoReCBenchmark  # noqa
+from .norec import NorecBenchmark  # noqa
 from .nordial import NorDialBenchmark  # noqa
 from .norne_nb import NorneNBBenchmark  # noqa
 from .norne_nn import NorneNNBenchmark  # noqa
@@ -25,3 +25,5 @@ from .fdt_pos import FdtPosBenchmark  # noqa
 from .fdt_dep import FdtDepBenchmark  # noqa
 from .wikiann_is import WikiannIsBenchmark  # noqa
 from .wikiann_fo import WikiannFoBenchmark  # noqa
+from .norec_is import NorecISBenchmark  # noqa
+from .norec_fo import NorecFOBenchmark  # noqa
