@@ -429,7 +429,7 @@ class BaseBenchmark(ABC):
                         new_clf.weight = new_clf_weight
                         model.classifier = new_clf
 
-                        # Update the number of labels the model think it has.
+                        # Update the number of labels the model thinks it has.
                         # This is required to avoid exceptions when evaluating
                         model.config.num_labels = len(model_id2label)
                         model.num_labels = len(model_id2label)
@@ -917,6 +917,17 @@ class BaseBenchmark(ABC):
                     progress_bar=progress_bar
                 )
 
+                # Check if the SpaCy model has been trained on the task at
+                # hand. If not, then skip this benchmark.
+                sample_preds = preds_labels[0][0]
+                pos_ner_test = (isinstance(sample_preds, list) and
+                                '' in sample_preds)
+                dep_test = (isinstance(sample_preds[0], list) and
+                            '' in sample_preds[0])
+                if pos_ner_test or dep_test:
+                    raise InvalidBenchmark('This SpaCy model have not been '
+                                           'trained on this task. Skipping.')
+
                 test_metrics = self._compute_metrics(preds_labels)
                 test_metrics = {f'test_{key}': val
                                 for key, val in test_metrics.items()}
